"""Define reactive tests."""

import subprocess
import unittest.mock as mock

from reactive import canonical_livepatch


@mock.patch("reactive.canonical_livepatch.check_output")
@mock.patch("charmhelpers.core.hookenv.log")
def test_disable_livepatch(log, check_output):
    """Test disable_livepatch succeeds and logs a reason."""
    result = canonical_livepatch.disable_livepatch("because it's a test")
    assert result, "Should have completed successfully"
    check_output.assert_called_once_with(
        ["/snap/bin/canonical-livepatch", "disable"],
        universal_newlines=True,
        stderr=subprocess.STDOUT,
    )
    log.assert_called_once_with("because it's a test")


@mock.patch(
    "reactive.canonical_livepatch.check_output",
    side_effect=subprocess.CalledProcessError(
        -1, cmd="my-test-command", output="Because things fail in tests"
    ),
)
@mock.patch("charmhelpers.core.hookenv.log")
def test_disable_livepatch_fails(log, check_output):
    """Test disable_livepatch fails to the log."""
    result = canonical_livepatch.disable_livepatch("because it's a test")
    assert not result, "Should have failed, but not raised"
    check_output.assert_called_once_with(
        ["/snap/bin/canonical-livepatch", "disable"],
        universal_newlines=True,
        stderr=subprocess.STDOUT,
    )
    assert log.call_count == 2, "Should have logged twice"
    log.assert_called_with(
        "Unable to deactivate: Command 'my-test-command' died with "
        "<Signals.SIGHUP: 1>.",
        "ERROR",
    )
